<?php

/**
 * Sample shortcode
 * @author alex
 */
class MyCustomShortcode extends ctShortcode
{

    /**
     * Group name to which shortcode should be assigned (for Shortcode Generator)
     * @return mixed|void
     */
    public function getGroupName()
    {
        return 'Custom';
    }

    /**
     * Returns shortcode label
     * @return mixed
     */
    public function getName()
    {
        return "My Custom Shortcode"; //this name is visible in shortcode generator
    }

    /**
     * Register javascript files - they will be added at the bottom of HTML
     * @see wp_footer
     */

    public function enqueueScripts()
    {
        //let's add some javascripts for this shortcode. It will be only loaded if shortcode is used.
        //CT_THEME_ASSETS points to theme_name/assets/
        wp_register_script('ct-sample-script', CT_THEME_ASSETS . '/js/ct-sample-script', array('jquery'));
        wp_enqueue_script('ct-sample-script');
    }

    /**
     * Add CSS styles
     */
    public function enqueueHeadScripts()
    {
        //add some styles
        //CT_THEME_ASSETS points to theme_name/assets/
        wp_register_style('ct-sample-style', CT_THEME_ASSETS . '/css/ct-sample-style.css');
        wp_enqueue_style('ct-sample-style');
    }

    /**
     * Returns shortcode name
     * @return string
     */
    public function getShortcodeName()
    {
        return 'my_shortcode'; //name used as a shortcode [my_shortcode]
    }

    /**
     * Handles shortcode
     * @param $atts
     * @param null $content
     * @return mixed
     */
    public function handle($atts, $content = null)
    {
        //extract our variables - now all variables from getAttributes may be used
        extract(shortcode_atts($this->extractShortcodeAttributes($atts), $atts));
        //this is where we can implement our custom HTML
        $classes = array('btn');
        $classes[] = $bigger == 'true' ? 'bigger' : 'standard'; //we check whether bigger option is used
        $classes[] = $align == 'left' ? 'left' : 'right';

        return '<a title="' . esc_attr($title) . '" class="' . esc_attr(implode($classes)) . '" href="' . esc_attr($url) . '">' . $content . '</a>';
    }

    /**
     * Returns config attributes
     * @return array
     */
    public function getAttributes()
    {
        /**
         * for shortcode generator and handle - define what parameters our shortcode has
         * examples can be found in your theme directory ex. dish/theme/shortcodes/
         * Key is the parameter name we will use and values are the definition
         **/
        return array(
            'title' => array('label' => __('Link title', 'ct_theme'), 'default' => __('Click Here', 'ct_theme'), 'type' => 'input', 'help' => __("Link title", 'ct_theme')),
            'url' => array('label' => __('URL', 'ct_theme'), 'default' => '', 'type' => 'input', 'help' => __("URL where our button should point", 'ct_theme')),

            'bigger' => array('label' => __('Bigger button?', 'ct_theme'), 'type' => "checkbox", 'default' => 'true'),
            'align' => array('label' => __('Alignment', 'ct_theme'), 'default' => 'left', 'type' => 'select', 'choices' => array('left' => __('left', 'ct_theme'), 'right' => __('right', 'ct_theme'))),
            'content' => array('label' => __('content', 'ct_theme'), 'default' => '', 'type' => "textarea"), //content name has a special meaning and is used when our shortcode supports content inside: [shortcode]CONTENT[/shortcode]
        );
    }
}